import { useEffect, useState } from 'react';
import { getDisplayImage, getDisplayTitle } from '../utils';
import { useChatContext } from '../../../context';
export const useChannelPreviewInfo = (props) => {
    const { channel, overrideImage, overrideTitle } = props;
    const { client } = useChatContext('useChannelPreviewInfo');
    const [displayTitle, setDisplayTitle] = useState(() => overrideTitle || getDisplayTitle(channel, client.user));
    const [displayImage, setDisplayImage] = useState(() => overrideImage || getDisplayImage(channel, client.user));
    useEffect(() => {
        if (overrideTitle && overrideImage)
            return;
        const updateTitles = () => {
            if (!overrideTitle)
                setDisplayTitle(getDisplayTitle(channel, client.user));
            if (!overrideImage)
                setDisplayImage(getDisplayImage(channel, client.user));
        };
        updateTitles();
        client.on('user.updated', updateTitles);
        return () => {
            client.off('user.updated', updateTitles);
        };
    }, [channel, channel.data, client, overrideImage, overrideTitle]);
    return {
        displayImage: overrideImage || displayImage,
        displayTitle: overrideTitle || displayTitle,
    };
};
